@@ -1,4 +1,6 @@
 package TestAdditional;
+use strict;
+use warnings;
 
 sub test_additional { return "test_additional"; }
 
